==> lxqt-panel-0.14.0.tar.xz: lxqt-panel-0.14.0/plugin-spacer/translations/spacer_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>SpacerConfiguration</name>
    <message>
        <location filename="../spacerconfiguration.ui" line="14"/>
        <source>Spacer Settings</source>
        <translation>Pengaturan Pemisah</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="20"/>
        <source>Space width:</source>
        <translation>Lebar pemisah:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="40"/>
        <source>Space type:</source>
        <translation>Tipe pemisah:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="57"/>
        <source>fixed</source>
        <translation>tetap</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="71"/>
        <source>expandable</source>
        <translation>dapat diperluas</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="34"/>
        <source>lined</source>
        <translation>garis</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="35"/>
        <source>dotted</source>
        <translation>titik</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="36"/>
        <source>invisible</source>
        <translation>tidak terlihat</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.2.0.tar.xz: lxqt-panel-2.2.0/plugin-spacer/translations/spacer_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>SpacerConfiguration</name>
    <message>
        <location filename="../spacerconfiguration.ui" line="14"/>
        <source>Spacer Settings</source>
        <translation>Pengaturan Pemisah</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="20"/>
        <source>Space width:</source>
        <translation>Lebar pemisah:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="54"/>
        <source>Space type:</source>
        <translation>Tipe pemisah:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="27"/>
        <source>fixed</source>
        <translation>tetap</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="47"/>
        <source>expandable</source>
        <translation>dapat diperluas</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="34"/>
        <source>lined</source>
        <translation>bergaris</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="35"/>
        <source>dotted</source>
        <translation>titik</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="36"/>
        <source>invisible</source>
        <translation>tidak terlihat</translation>
    </message>
</context>
</TS>
